==> haskell-http-streams-0.8.9.9-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-yQ9crZGHxE7m8n6p8T4rP
key:                  http-streams-0.8.9.9-yQ9crZGHxE7m8n6p8T4rP
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  f92d69e33971731e0b0bf92ce90430df
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-yQ9crZGHxE7m8n6p8T4rP
depends:
    HsOpenSSL-0.11.7.9-4zdXUDvk3kbBJwucU20WNX
    aeson-2.1.2.1-2383fjET7FWJSHJW4VQuW
    attoparsec-0.14.4-H9Y4iLHDqcP1CPr5BByOUl
    attoparsec-aeson-2.1.0.0-JiHEPoU6Hkc7CxEyeQGu8D base-4.17.2.1
    base64-bytestring-1.2.1.0-G53UOvB3pKB2mwL6yBWItW
    blaze-builder-0.4.4-J87LvVgADYa5gww986bADm bytestring-0.11.5.3
    case-insensitive-1.2.1.0-L5gSnJGPP5IIfg5Ct42zAo directory-1.3.7.1
    filepath-1.4.2.2 http-common-0.8.3.4-JJ6KC6zUFYIH40J0vuL2My
    io-streams-1.5.2.2-Ho3Z3R7nkl3FEU94utWzwP mtl-2.2.2
    network-3.1.4.0-AsoxBmMP1pfJSzv0IgKvnl
    network-uri-2.6.4.2-JT5mjmfFxkg6DEC2jAgmZ6
    openssl-streams-1.2.3.0-Lj6JmKR0vi1KaQyDdSuh3L text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-AeV3HTkHtCc6BQ9fzLSSB8

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.9.9-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-I4sFd5tfv9s7ajTg0avE3v
key:                  http-streams-0.8.9.9-I4sFd5tfv9s7ajTg0avE3v
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  5f898a8c553981ce6247b9bf19c71d42
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-I4sFd5tfv9s7ajTg0avE3v
depends:
    HsOpenSSL-0.11.7.9-mAci6xXuEb3ZJRGhx0O78
    aeson-2.1.2.1-BWqAP5DPS0iMNSAJtMWSf
    attoparsec-0.14.4-7XWZ3nsZOGKJDEorzXp6qF
    attoparsec-aeson-2.1.0.0-FXj7tOmtjxCJauw5Ev0wtT base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb
    blaze-builder-0.4.4-EYzzAuOKf5mlUrLaPwbAW bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GKEaqjX3nXNEZmMRebSTRD directory-1.3.7.1
    filepath-1.4.2.2 http-common-0.8.3.4-6bxv9CTRQZAJ42qAvgkmAF
    io-streams-1.5.2.2-5D87hnUxjPiLngsPKEMdZF mtl-2.2.2
    network-3.1.4.0-Be19ySMD4vC3IuDyb1IMcQ
    network-uri-2.6.4.2-CScpRPfTOboAxTStoroPUs
    openssl-streams-1.2.3.0-23Z3rVyRWzM4EE2SxYhBsT text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
